@@ -263,6 +263,20 @@ def cli_qa_delete(obj, qa_hash):
     QA("delete", obj["project"], obj["config"], obj["tokens"], qa_hash).run()
 
 
+@qa.command("freeze", help="Freeze QA env")
+@click.argument("qa_hash", required=True)
+@click.pass_obj
+def cli_qa_freeze(obj, qa_hash):
+    QA("freeze", obj["project"], obj["config"], obj["tokens"], qa_hash).run()
+
+
+@qa.command("unfreeze", help="Unfreeze QA env")
+@click.argument("qa_hash", required=True)
+@click.pass_obj
+def cli_qa_unfreeze(obj, qa_hash):
+    QA("unfreeze", obj["project"], obj["config"], obj["tokens"], qa_hash).run()
+
+
 @qa.command("check", help="Check QA conf")
 @click.pass_obj
 def cli_qa_check(obj):
