@@ -32,6 +32,10 @@ class QA:
             self._update()
         elif self._action == "delete":
             self._delete()
+        elif self._action == "freeze":
+            self._freeze()
+        elif self._action == "unfreeze":
+            self._unfreeze()
         elif self._action == "check":
             self._check()
         elif self._action == "describe":
@@ -61,7 +65,7 @@ class QA:
 
         # add filtering
         filters = []
-        status_values = '"created","creating","updated","updating","failed"'
+        status_values = '"created","creating","updated","updating","failed","frozen"'
         if len(self._flags["status"]) > 0:
             status_values = ",".join(
                 [f'"{status}"' for status in self._flags["status"]]
@@ -182,6 +186,24 @@ class QA:
         logger.info("QA deletion initiated")
         logger.debug(json.dumps(r.json(), indent=2))
 
+    def _freeze(self):
+        qa_hash = self._flags
+
+        body = {"operation": "freeze"}
+        logger.debug(json.dumps(body))
+        r = self._qainit.execute("PUT", f"/api/v1/qa/{qa_hash}", body=json.dumps(body))
+        logger.info("QA freezing initiated")
+        logger.debug(json.dumps(r.json(), indent=2))
+
+    def _unfreeze(self):
+        qa_hash = self._flags
+
+        body = {"operation": "unfreeze"}
+        logger.debug(json.dumps(body))
+        r = self._qainit.execute("PUT", f"/api/v1/qa/{qa_hash}", body=json.dumps(body))
+        logger.info("QA unfreezing initiated")
+        logger.debug(json.dumps(r.json(), indent=2))
+
     def _create(self):
         r = self._qainit.execute("GET", "/api/v1/user")
         r = r.json()
