@@ -136,7 +136,9 @@ class Release:
                     max(rel["version"] for rel in current)
                 )
             else:
-                releases = self._get_releases_since("0.1.0")  # default
+                releases = self._get_releases_since(
+                    semver.VersionInfo.parse("0.1.0")
+                )  # default
             if not releases:
                 logger.error(f"No new release found for project {self._project}!")
                 sys.exit(-1)
@@ -228,16 +230,12 @@ class Release:
     def _get_releases_since(self, threshold):
         releases = self._repo.get_releases().get_page(0)
 
-        return [
-            rel for rel in releases if semver.compare(threshold, rel.tag_name) == -1
-        ][0:4]
+        return [rel for rel in releases if threshold.compare(rel.tag_name) == -1][0:4]
 
     def _get_releases_before(self, threshold):
         releases = self._repo.get_releases().get_page(0)
 
-        return [
-            rel for rel in releases if semver.compare(threshold, rel.tag_name) == 1
-        ][0:4]
+        return [rel for rel in releases if threshold.compare(rel.tag_name) == 1][0:4]
 
     def _manage_youtrack_card(self, version, countries):
         release_state = self._config.youtrack["release_state"]
